package com.ruoyi.mall.service;

import java.util.List;
import com.ruoyi.mall.domain.MallMemberSearchHistory;
import com.ruoyi.mall.domain.MallMemberSearchHistoryDto;

/**
 * mallService接口
 * 
 * @author ruoyi
 * @date 2021-12-23
 */
public interface IMallMemberSearchHistoryService 
{
    /**
     * 查询mall
     * 
     * @param id mall主键
     * @return mall
     */
    public MallMemberSearchHistory selectMallMemberSearchHistoryById(Long id);

    /**
     * 查询mall列表
     * 
     * @param mallMemberSearchHistory mall
     * @return mall集合
     */
    public List<MallMemberSearchHistoryDto> selectMallMemberSearchHistoryList(MallMemberSearchHistory mallMemberSearchHistory);

    /**
     * 新增mall
     * 
     * @param mallMemberSearchHistory mall
     * @return 结果
     */
    public int insertMallMemberSearchHistory(MallMemberSearchHistory mallMemberSearchHistory);

    /**
     * 修改mall
     * 
     * @param mallMemberSearchHistory mall
     * @return 结果
     */
    public int updateMallMemberSearchHistory(MallMemberSearchHistory mallMemberSearchHistory);

    /**
     * 批量删除mall
     * 
     * @param ids 需要删除的mall主键集合
     * @return 结果
     */
    public int deleteMallMemberSearchHistoryByIds(Long[] ids);

    /**
     * 删除mall信息
     * 
     * @param id mall主键
     * @return 结果
     */
    public int deleteMallMemberSearchHistoryById(Long id);

    /**/
    public int deleteMallMemberSearchHistoryByUserId(Long userId);
}
